@@ -20,7 +20,7 @@ import re
 
 from clade.extensions.abstract import Extension
 from clade.extensions.callgraph import Callgraph
-from clade.extensions.utils import nested_dict, traverse
+from clade.types.nested_dict import nested_dict, traverse
 
 
 class CrossRef(Callgraph):
@@ -55,8 +55,6 @@ class CrossRef(Callgraph):
         self.log("Calculating 'from' references")
         self.__gen_ref_from(locations)
 
-        self.log("Calculating finished")
-
     def load_ref_to_by_file(self, files=None):
         """Load references to definitions and declarations grouped by files."""
         return self.load_data_by_key(self.ref_to_folder, files)
