@@ -19,7 +19,7 @@ from clade.extensions.abstract import Extension
 class SrcGraph(Extension):
     __version__ = "1"
 
-    always_requires = ["CmdGraph"]
+    always_requires = ["CmdGraph", "Storage"]
     requires = always_requires + ["CC", "CL"]
 
     def __init__(self, work_dir, conf=None):
@@ -31,14 +31,14 @@ class SrcGraph(Extension):
         super().__init__(work_dir, conf)
 
         self.src_graph = dict()
-        self.src_graph_archive = "src_graph.zip"
+        self.src_graph_folder = "src_graph"
 
         self.src_info = dict()
         self.src_info_file = "src_info.json"
 
     def load_src_graph(self, files=None):
         """Load source graph."""
-        return self.load_data_by_key(self.src_graph_archive, files)
+        return self.load_data_by_key(self.src_graph_folder, files)
 
     def load_src_info(self):
         """Load information about source files."""
@@ -61,8 +61,8 @@ class SrcGraph(Extension):
             self.error("Source graph is empty")
             raise RuntimeError
 
-        self.dump_data(self.src_info, self.src_info_file, indent=4)
-        self.dump_data_by_key(self.src_graph, self.src_graph_archive)
+        self.dump_data(self.src_info, self.src_info_file)
+        self.dump_data_by_key(self.src_graph, self.src_graph_folder)
 
         self.src_graph.clear()
 
@@ -133,6 +133,9 @@ class SrcGraph(Extension):
 
     def __count_file_loc(self, file):
         """Count number of lines of code in the file."""
+        if self.conf.get("Compiler.store_deps"):
+            file = self.extensions["Storage"].get_storage_path(file)
+
         try:
             i = -1
             with open(file, "rb") as f:
