@@ -31,7 +31,7 @@ class Variables(Callgraph):
         super().__init__(work_dir, conf)
 
         self.variables = dict()
-        self.variables_archive = "variables.zip"
+        self.variables_folder = "variables"
 
         self.used_in_vars = dict()
         self.used_in_vars_file = "used_in_vars.json"
@@ -47,8 +47,9 @@ class Variables(Callgraph):
         self.__process_init_global()
         self._clean_error_log()
 
-        self.dump_data_by_key(self.variables, self.variables_archive)
-        self.dump_variables_data(self.used_in_vars, self.used_in_vars_file, indent=4)
+        # indent=4 may cause segfault inside ujson
+        self.dump_data_by_key(self.variables, self.variables_folder, indent=0)
+        self.dump_variables_data(self.used_in_vars, self.used_in_vars_file)
 
         self.functions.clear()
         self.src_graph.clear()
@@ -125,7 +126,7 @@ class Variables(Callgraph):
                     self.used_in_vars[func][possible_file].append(context_file)
 
     def load_variables(self, files=None):
-        return self.load_data_by_key(self.variables_archive, files)
+        return self.load_data_by_key(self.variables_folder, files)
 
     def load_used_in_vars(self):
         return self.load_data(self.used_in_vars_file)
